"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var day_1 = require("./day");
var date_fns_1 = require("date-fns");
/**
 * Converts a list of times from the API into structure data for the CLI.
 */
var DateRange = /** @class */ (function () {
    function DateRange(times) {
        var _this = this;
        this.days = new Array();
        this.total = new day_1.DayTotal();
        var timesToDays = [];
        times.forEach(function (time) {
            var newDay = new day_1.Day(time);
            timesToDays.push(newDay);
        });
        timesToDays.forEach(function (time) {
            var timeDay = date_fns_1.getDay(time.date);
            var dayIndex = _this.days.findIndex(function (day) {
                return timeDay === date_fns_1.getDay(day.date);
            });
            dayIndex < 0 ? _this.days.push(time) : _this.mergeDays(dayIndex, time);
        });
        this.total.worked = this.days.reduce(function (accumulator, currentValue) {
            var hours = currentValue.total.worked || 0;
            return accumulator + hours;
        }, 0);
    }
    DateRange.prototype.mergeDays = function (index, day) {
        var mergedDay = this.days[index];
        this.days[index].slots.worked = mergedDay.slots.worked.concat(day.slots.worked);
        mergedDay.total.worked = mergedDay.total.worked + day.total.worked;
        this.calcUnpaidBreak(index, day);
    };
    DateRange.prototype.calcUnpaidBreak = function (index, day) {
        var startTime = this.days[index].slots.worked[0].clockOut;
        var endTime = day.slots.worked[0].clockIn;
        var total = date_fns_1.differenceInMinutes(endTime, startTime) / 60;
        this.days[index].slots.unpaidBreak.push({
            clockIn: startTime,
            clockOut: endTime,
            hours: total
        });
        this.days[index].total.unpaidBreaks =
            this.days[index].total.unpaidBreaks + day.total.unpaidBreaks;
    };
    return DateRange;
}());
exports.DateRange = DateRange;
//# sourceMappingURL=date-range.js.map