"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var date_fns_1 = require("date-fns");
var chalk_1 = require("chalk");
var formatter_1 = require("../formatter");
var Calculator = /** @class */ (function () {
    function Calculator() {
        this.format = new formatter_1.default();
    }
    /**
     * Calculates the number of hours worked so far from right now.
     *
     * @param startTime The time you started working.
     * @param newTime The time right now to measure against. Defaults to now.
     * @returns the number of hours worked so far.
     */
    Calculator.prototype.hoursWorkedSoFar = function (startTime, nowTime) {
        if (nowTime === void 0) { nowTime = new Date(); }
        var minutesWorked = date_fns_1.differenceInMinutes(startTime, nowTime);
        return minutesWorked / 60;
    };
    Calculator.prototype.estimateEndTime = function (hours, comparison) {
        var difference = Number(hours - comparison) * -1;
        return date_fns_1.format(date_fns_1.addHours(new Date(), difference), "hh:mma");
    };
    /**
     * Converts a simple time string to a JavaScript date.
     *
     * @param time A simple time layout.
     * @returns A converted time in the date format.
     */
    Calculator.prototype.convertTimeToDate = function (time, date) {
        if (date === void 0) { date = new Date(); }
        var splitTime = time.split("").filter(function (i) { return !isNaN(i); });
        if (splitTime.length === 3)
            splitTime.unshift("0");
        var hour = Number("" + splitTime[0] + splitTime[1]);
        var minutes = Number("" + splitTime[2] + splitTime[3]);
        date.setHours(hour, minutes);
        return date;
    };
    /**
     * Finds the number of hours left against a compared amount.
     *
     * @param hours Number of hours worked
     * @param comparison Number of hours to compare with hours.
     * @returns the difference of the compared time in colored hours.
     */
    Calculator.prototype.difference = function (hours, comparison) {
        var difference = Number((hours - comparison).toFixed(2));
        var differenceOut = "";
        switch (true) {
            case difference > 0:
                differenceOut = chalk_1.default.green("+" + this.format.hours(difference));
                break;
            case difference == 0:
                differenceOut = chalk_1.default.yellow(" " + this.format.hours(0));
                break;
            case difference < 0:
                differenceOut = chalk_1.default.red("-" + this.format.hours(Math.abs(difference)));
            default:
                difference;
        }
        return differenceOut;
    };
    return Calculator;
}());
exports.default = Calculator;
//# sourceMappingURL=calculator.js.map